@@ -79,7 +79,7 @@ geocode_reverse_init (GeocodeReverse *object)
 	object->priv = G_TYPE_INSTANCE_GET_PRIVATE ((object), GEOCODE_TYPE_REVERSE, GeocodeReversePrivate);
 	object->priv->ht = g_hash_table_new_full (g_str_hash, g_str_equal,
 						  g_free, g_free);
-        object->priv->soup_session = soup_session_new ();
+	object->priv->soup_session = _geocode_glib_build_soup_session ();
 }
 
 /**
@@ -114,6 +114,32 @@ geocode_reverse_new_for_location (GeocodeLocation *location)
 	return object;
 }
 
+static void
+insert_bounding_box_element (GHashTable *ht,
+			     GType       value_type,
+			     const char *name,
+			     JsonReader *reader)
+{
+	if (value_type == G_TYPE_STRING) {
+		const char *bbox_val;
+
+		bbox_val = json_reader_get_string_value (reader);
+		g_hash_table_insert (ht, g_strdup (name), g_strdup (bbox_val));
+	} else if (value_type == G_TYPE_DOUBLE) {
+		gdouble bbox_val;
+
+		bbox_val = json_reader_get_double_value (reader);
+		g_hash_table_insert(ht, g_strdup (name), g_strdup_printf ("%lf", bbox_val));
+	} else if (value_type == G_TYPE_INT64) {
+		gint64 bbox_val;
+
+		bbox_val = json_reader_get_double_value (reader);
+		g_hash_table_insert(ht, g_strdup (name), g_strdup_printf ("%"G_GINT64_FORMAT, bbox_val));
+	} else {
+		g_debug ("Unhandled node type %s for %s", g_type_name (value_type), name);
+	}
+}
+
 void
 _geocode_read_nominatim_attributes (JsonReader *reader,
                                     GHashTable *ht)
@@ -126,6 +152,10 @@ _geocode_read_nominatim_attributes (JsonReader *reader,
 	is_address = (g_strcmp0 (json_reader_get_member_name (reader), "address") == 0);
 
 	members = json_reader_list_members (reader);
+        if (members == NULL) {
+                json_reader_end_member (reader);
+                return;
+        }
 
 	for (i = 0; members[i] != NULL; i++) {
                 const char *value = NULL;
@@ -164,25 +194,26 @@ _geocode_read_nominatim_attributes (JsonReader *reader,
                         }
                 } else if (g_strcmp0 (members[i], "boundingbox") == 0) {
                         const char *bbox_val;
+                        JsonNode *node;
+                        GType value_type;
 
                         json_reader_read_element (reader, 0);
-                        bbox_val = json_reader_get_string_value (reader);
-                        g_hash_table_insert(ht, g_strdup ("boundingbox-bottom"), g_strdup (bbox_val));
+                        node = json_reader_get_value (reader);
+                        value_type = json_node_get_value_type (node);
+
+                        insert_bounding_box_element (ht, value_type, "boundingbox-bottom", reader);
                         json_reader_end_element (reader);
 
                         json_reader_read_element (reader, 1);
-                        bbox_val = json_reader_get_string_value (reader);
-                        g_hash_table_insert(ht, g_strdup ("boundingbox-top"), g_strdup (bbox_val));
+                        insert_bounding_box_element (ht, value_type, "boundingbox-top", reader);
                         json_reader_end_element (reader);
 
                         json_reader_read_element (reader, 2);
-                        bbox_val = json_reader_get_string_value (reader);
-                        g_hash_table_insert(ht, g_strdup ("boundingbox-left"), g_strdup (bbox_val));
+                        insert_bounding_box_element (ht, value_type, "boundingbox-left", reader);
                         json_reader_end_element (reader);
 
                         json_reader_read_element (reader, 3);
-                        bbox_val = json_reader_get_string_value (reader);
-                        g_hash_table_insert(ht, g_strdup ("boundingbox-right"), g_strdup (bbox_val));
+                        insert_bounding_box_element (ht, value_type, "boundingbox-right", reader);
                         json_reader_end_element (reader);
                 }
                 json_reader_end_member (reader);
@@ -513,8 +544,11 @@ geocode_reverse_resolve (GeocodeReverse *object,
 	g_free (contents);
 	g_object_unref (query);
 
-        place = _geocode_create_place_from_attributes (result);
-        g_hash_table_destroy (result);
+	if (result == NULL)
+		return NULL;
+
+	place = _geocode_create_place_from_attributes (result);
+	g_hash_table_destroy (result);
 
 	return place;
 }
